@@ -40,11 +40,12 @@
 #include "opensearchmanager.h"
 
 // Widget Includes
-#include "networkwidget.h"
-#include "generalwidget.h"
+#include "advancedwidget.h"
 #include "appearancewidget.h"
-#include "webkitwidget.h"
+#include "generalwidget.h"
+#include "privacywidget.h"
 #include "tabswidget.h"
+#include "webkitwidget.h"
 
 // KDE Includes
 #include <KConfig>
@@ -68,7 +69,8 @@ private:
     TabsWidget *tabsWidg;
     AppearanceWidget *appearanceWidg;
     WebKitWidget *webkitWidg;
-    NetworkWidget *networkWidg;
+    PrivacyWidget *privacyWidg;
+    AdvancedWidget *advancedWidg;
 
     KCModuleProxy *ebrowsingModule;
 
@@ -109,10 +111,16 @@ Private::Private(SettingsDialog *parent)
     pageItem->setIcon(webkitIcon);
 
     // -- 5
-    networkWidg = new NetworkWidget(parent);
-    networkWidg->layout()->setMargin(0);
-    pageItem = parent->addPage(networkWidg , i18n("Network"));
-    pageItem->setIcon(KIcon("preferences-system-network"));
+    privacyWidg = new PrivacyWidget(parent);
+    privacyWidg->layout()->setMargin(0);
+    pageItem = parent->addPage(privacyWidg, i18n("Privacy"));
+    pageItem->setIcon(KIcon("view-media-artist"));
+
+    // -- 6
+    advancedWidg = new AdvancedWidget(parent);
+    advancedWidg->layout()->setMargin(0);
+    pageItem = parent->addPage(advancedWidg, i18n("Advanced"));
+    pageItem->setIcon(KIcon("applications-system"));
 
     // -- 7
     shortcutsEditor = new KShortcutsEditor(rApp->mainWindow()->actionCollection(), parent);
@@ -133,7 +141,7 @@ Private::Private(SettingsDialog *parent)
     // WARNING
     // remember wheh changing here that the smallest netbooks
     // have a 1024x576 resolution. So DON'T bother that limits!!
-    parent->setMinimumSize(700, 576);
+    parent->setMinimumSize(700, 525);
 }
 
 
@@ -146,53 +154,48 @@ SettingsDialog::SettingsDialog(QWidget *parent)
 {
     showButtonSeparator(false);
     setWindowTitle(i18nc("Window title of the settings dialog", "Configure – rekonq"));
-    setModal(true);
-
-    readConfig();
 
     // update buttons
     connect(d->generalWidg,     SIGNAL(changed(bool)), this, SLOT(updateButtons()));
     connect(d->tabsWidg,        SIGNAL(changed(bool)), this, SLOT(updateButtons()));
     connect(d->appearanceWidg,  SIGNAL(changed(bool)), this, SLOT(updateButtons()));
     connect(d->webkitWidg,      SIGNAL(changed(bool)), this, SLOT(updateButtons()));
-    connect(d->networkWidg,     SIGNAL(changed(bool)), this, SLOT(updateButtons()));
     connect(d->ebrowsingModule, SIGNAL(changed(bool)), this, SLOT(updateButtons()));
+    connect(d->advancedWidg,    SIGNAL(changed(bool)), this, SLOT(updateButtons()));
+    connect(d->privacyWidg,     SIGNAL(changed(bool)), this, SLOT(updateButtons()));
+
     connect(d->shortcutsEditor, SIGNAL(keyChange()),   this, SLOT(updateButtons()));
 
     // save settings
     connect(this, SIGNAL(applyClicked()), this, SLOT(saveSettings()));
     connect(this, SIGNAL(okClicked()),    this, SLOT(saveSettings()));
+    setHelp("Config-rekonq", "rekonq");
 }
 
 
 SettingsDialog::~SettingsDialog()
 {
+    kDebug() << "bye bye settings...";
     delete d;
 }
 
 
-// we need this function to UPDATE the config widget data..
-void SettingsDialog::readConfig()
-{
-}
-
-
 // we need this function to SAVE settings in rc file..
 void SettingsDialog::saveSettings()
 {
-    if (!hasChanged())
-        return;
-
     ReKonfig::self()->writeConfig();
 
     d->generalWidg->save();
     d->tabsWidg->save();
     d->appearanceWidg->save();
     d->webkitWidg->save();
-    d->networkWidg->save();
+    d->advancedWidg->save();
+    d->privacyWidg->save();
     d->shortcutsEditor->save();
     d->ebrowsingModule->save();
 
+    d->privacyWidg->reload();
+
     SearchEngine::reload();
     rApp->opensearchManager()->removeDeletedEngines();
 
@@ -208,7 +211,8 @@ bool SettingsDialog::hasChanged()
            || d->tabsWidg->changed()
            || d->appearanceWidg->changed()
            || d->webkitWidg->changed()
-           || d->networkWidg->changed()
+           || d->advancedWidg->changed()
+           || d->privacyWidg->changed()
            || d->ebrowsingModule->changed()
            || d->shortcutsEditor->isModified();
     ;
