@@ -131,7 +131,7 @@ QSize TabBar::tabSizeHint(int index) const
         }
     }
 
-    int h = view->addTabButton()->height() + 6;
+    int h = KTabBar::tabSizeHint(index).height();
 
     QSize ts = QSize(w, h);
     return ts;
@@ -195,20 +195,27 @@ void TabBar::showTabPreview()
     if (indexedTab->isPageLoading())
         return;
 
-    int w = (mv->sizeHint().width() / baseWidthDivisor);
+    // Make sure the hovered webtab match the current size
+    // Only the active one is updated by window resize events
+    indexedTab->resize(currentTab->size());
 
     m_previewPopup = new TabPreviewPopup(indexedTab , this);
 
+    int tabWidth = tabSizeHint(m_currentTabPreviewIndex).width();
     int tabBarWidth = mv->size().width();
-    int leftIndex = tabRect(m_currentTabPreviewIndex).x() + (tabRect(m_currentTabPreviewIndex).width() - w) / 2;
+    int leftIndex = tabRect(m_currentTabPreviewIndex).x() + (tabRect(m_currentTabPreviewIndex).width() - tabWidth) / 2;
+    int popupWidth = m_previewPopup.data()->thumbnailSize().width();
+
+    // Center the popup if the tab width is bigger or smaller
+    leftIndex += (tabWidth - popupWidth) / 2;
 
     if (leftIndex < 0)
     {
         leftIndex = 0;
     }
-    else if (leftIndex + w > tabBarWidth)
+    else if (leftIndex + tabWidth > tabBarWidth)
     {
-        leftIndex = tabBarWidth - w;
+        leftIndex = tabBarWidth - tabWidth;
     }
 
     QPoint pos(leftIndex, tabRect(m_currentTabPreviewIndex).y() + tabRect(m_currentTabPreviewIndex).height());
@@ -552,3 +559,10 @@ bool TabBar::isURLValid(const QString &url)
         isValid = true;
     return isValid;
 }
+
+
+void TabBar::tabLayoutChange()
+{
+    KTabBar::tabLayoutChange();
+    emit tabLayoutChanged();
+}
