@@ -41,6 +41,7 @@
 #include <KIcon>
 #include <KLineEdit>
 #include <KRatingWidget>
+#include <KBookmarkDialog>
 
 // Qt Includes
 #include <QDialogButtonBox>
@@ -67,13 +68,13 @@
 
 BookmarkWidget::BookmarkWidget(const KBookmark &bookmark, QWidget *parent)
     : QMenu(parent)
-    , m_bookmark(new KBookmark(bookmark))
+    , m_bookmark(bookmark)
 {
     setAttribute(Qt::WA_DeleteOnClose);
     setFixedWidth(320);
 
 #ifdef HAVE_NEPOMUK
-    m_nfoResource = (QUrl)m_bookmark->url();
+    m_nfoResource = (QUrl)m_bookmark.url();
     m_isNepomukEnabled = QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.NepomukServer");
     kDebug() << "IS NEPOMUK ACTUALLY RUNNING? " << m_isNepomukEnabled;
 #endif
@@ -106,18 +107,19 @@ BookmarkWidget::BookmarkWidget(const KBookmark &bookmark, QWidget *parent)
     m_folder = new KComboBox(this);
     layout->addRow(folderLabel, m_folder);
     setupFolderComboBox();
+    connect(m_folder, SIGNAL(currentIndexChanged(int)), this, SLOT(onFolderIndexChanged(int)));
 
     // Bookmark name
     QLabel *nameLabel = new QLabel(this);
     nameLabel->setText(i18n("Name:"));
     m_name = new KLineEdit(this);
-    if (m_bookmark->isNull())
+    if (m_bookmark.isNull())
     {
         m_name->setEnabled(false);
     }
     else
     {
-        m_name->setText(m_bookmark->text());
+        m_name->setText(m_bookmark.text());
         m_name->setFocus();
     }
     layout->addRow(nameLabel, m_name);
@@ -193,12 +195,6 @@ BookmarkWidget::BookmarkWidget(const KBookmark &bookmark, QWidget *parent)
 }
 
 
-BookmarkWidget::~BookmarkWidget()
-{
-    delete m_bookmark;
-}
-
-
 void BookmarkWidget::showAt(const QPoint &pos)
 {
     adjustSize();
@@ -211,17 +207,17 @@ void BookmarkWidget::showAt(const QPoint &pos)
 
 void BookmarkWidget::accept()
 {
-    if (!m_bookmark->isNull() && m_name->text() != m_bookmark->fullText())
+    if (!m_bookmark.isNull() && m_name->text() != m_bookmark.fullText())
     {
-        m_bookmark->setFullText(m_name->text());
+        m_bookmark.setFullText(m_name->text());
         rApp->bookmarkManager()->emitChanged();
     }
     QString folderAddress = m_folder->itemData(m_folder->currentIndex()).toString();
     KBookmarkGroup a = rApp->bookmarkManager()->manager()->findByAddress(folderAddress).toGroup();
 
-    KBookmarkGroup parent = m_bookmark->parentGroup();
-    parent.deleteBookmark(*m_bookmark);
-    a.addBookmark(*m_bookmark);
+    KBookmarkGroup parent = m_bookmark.parentGroup();
+    parent.deleteBookmark(m_bookmark);
+    a.addBookmark(m_bookmark);
     rApp->bookmarkManager()->manager()->emitChanged(a);
 
 #ifdef HAVE_NEPOMUK
@@ -237,50 +233,73 @@ void BookmarkWidget::accept()
 
 void BookmarkWidget::setupFolderComboBox()
 {
-    KBookmarkGroup root = rApp->bookmarkManager()->manager()->toolbar();
+    KBookmarkGroup toolBarRoot = rApp->bookmarkManager()->manager()->toolbar();
+    KBookmarkGroup root = rApp->bookmarkManager()->rootGroup();
 
-    if (rApp->bookmarkManager()->manager()->toolbar().address() == rApp->bookmarkManager()->manager()->root().address())
+    if (toolBarRoot.address() == root.address())
     {
-        m_folder->addItem(i18n("Bookmark Toolbar"),
-                          rApp->bookmarkManager()->manager()->toolbar().address());
+        m_folder->addItem(KIcon("bookmark-toolbar"),
+                          i18n("Bookmark Toolbar"),
+                          toolBarRoot.address());
     }
     else
     {
-        m_folder->addItem(rApp->bookmarkManager()->manager()->toolbar().text(),
-                          rApp->bookmarkManager()->manager()->toolbar().address());
+        m_folder->addItem(KIcon("bookmark-toolbar"),
+                          toolBarRoot.text(),
+                          toolBarRoot.address());
     }
     m_folder->insertSeparator(1);
 
-    if (m_bookmark->parentGroup().address() != rApp->bookmarkManager()->manager()->toolbar().address())
+    if (m_bookmark.parentGroup().address() != toolBarRoot.address())
     {
-        m_folder->addItem(m_bookmark->parentGroup().text(),
-                          m_bookmark->parentGroup().address());
+        QString parentText = m_bookmark.parentGroup().text();
+
+        if (m_bookmark.parentGroup().address() == root.address())
+        {
+            parentText = i18n("Root folder");
+        }
+
+        m_folder->addItem(parentText,
+                          m_bookmark.parentGroup().address());
         m_folder->insertSeparator(3);
     }
 
-    for (KBookmark bookmark = root.first(); !bookmark.isNull(); bookmark = root.next(bookmark))
+    for (KBookmark bookmark = toolBarRoot.first(); !bookmark.isNull(); bookmark = toolBarRoot.next(bookmark))
     {
-        if (bookmark.isGroup())
+        if (bookmark.isGroup() && bookmark.address() != m_bookmark.parentGroup().address())
         {
             m_folder->addItem(bookmark.text(), bookmark.address());
         }
     }
 
-    if (m_bookmark->parentGroup().address() == root.address())
+    m_folder->insertSeparator(m_folder->count());
+    m_folder->addItem(KIcon("folder"), i18n("Choose..."));
+
+    int index =  m_folder->findData(m_bookmark.parentGroup().address());
+    m_folder->setCurrentIndex(index);
+}
+
+
+void BookmarkWidget::onFolderIndexChanged(int index)
+{
+    if (index == m_folder->count() - 1)
     {
-        m_folder->setCurrentIndex(0);
-    }
-    else
-    {
-        int index = m_folder->findText(m_bookmark->parentGroup().text());
-        m_folder->setCurrentIndex(index);
+        KBookmarkDialog dialog(rApp->bookmarkManager()->manager());
+        KBookmarkGroup selectedGroup = dialog.selectFolder(m_bookmark.parentGroup());
+
+        if (selectedGroup.address() != m_bookmark.parentGroup().address() && !selectedGroup.isNull() )
+        {
+            m_bookmark.parentGroup().deleteBookmark(m_bookmark);
+            selectedGroup.addBookmark(m_bookmark);
+            rApp->bookmarkManager()->manager()->emitChanged();
+        }
     }
 }
 
 
 void BookmarkWidget::removeBookmark()
 {
-    rApp->bookmarkManager()->owner()->deleteBookmark(*m_bookmark);
+    rApp->bookmarkManager()->owner()->deleteBookmark(m_bookmark);
     close();
 
     emit updateIcon();
