@@ -32,7 +32,7 @@
 #include "rekonq_defines.h"
 
 // Local Includes
-#include "listitem.h"
+#include "urlresolver.h"
 
 // KDE Includes
 #include <KService>
@@ -40,6 +40,9 @@
 // Qt Includes
 #include <QFrame>
 
+// Forward Declarations
+class ListItem;
+
 
 class CompletionWidget : public QFrame
 {
